{% use_layout "admin/layout.html" %}

<{ admin_table_widget title="Users" searchform=True }>
  <thead>
    <tr>
      <th>Username</th>
      <th>Email</th>
      <th>Signup at</th>
      <th>Last login at</th>
    </tr>
  </thead>
  <tbody>
  </tbody>
</{}>